@@ -2317,9 +2317,9 @@ log.pt <- function(x, df){
 
 .onAttach <- function(library, pkg)
 {
-  Rv <- R.Version()
-  if(Rv$major < 2 |(Rv$major == 2 && Rv$minor < 2.0))
-    stop("This package requires R 2.2.0 or later")
+  # Rv <- R.Version()
+  # if(Rv$major < 2 |(Rv$major == 2 && Rv$minor < 2.0))
+  #  stop("This package requires R 2.2.0 or later")
   if(interactive())
   {
     meta <- packageDescription("sn")
